pub struct BucketObjectLockDefault {
pub mode: LockMode,
pub retention_days: u32,
}Expand description
Per-bucket default retention. Applied automatically to new objects on PUT (only when no explicit per-object retention was supplied and no state already exists for the (bucket, key)).
Fields
mode: LockModeretention_days: u32Trait Implementations
Sourceimpl Clone for BucketObjectLockDefault
impl Clone for BucketObjectLockDefault
Sourcefn clone(&self) -> BucketObjectLockDefault
fn clone(&self) -> BucketObjectLockDefault
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BucketObjectLockDefault
impl Debug for BucketObjectLockDefault
Sourceimpl<'de> Deserialize<'de> for BucketObjectLockDefault
impl<'de> Deserialize<'de> for BucketObjectLockDefault
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BucketObjectLockDefault
impl PartialEq for BucketObjectLockDefault
Sourcefn eq(&self, other: &BucketObjectLockDefault) -> bool
fn eq(&self, other: &BucketObjectLockDefault) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BucketObjectLockDefault
impl Serialize for BucketObjectLockDefault
impl Copy for BucketObjectLockDefault
impl Eq for BucketObjectLockDefault
impl StructuralPartialEq for BucketObjectLockDefault